rosina

package module
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2026 License: MIT Imports: 3 Imported by: 1

README

Rosina -- Go test helpers

Status

  • The project currently does not accept Pull Requests.
  • Work in progress, API heavily unstable, not ready for use.

About the name Rosina

The name Rosina is a humble homage to Rosina Ferrario, the first Italian woman airplane pilot and airplane tester. She received her license in 1913. From the Wikipedia page in Italian you can find also other languages.

AI policy

This project does not accept contributions of any form (code, documentation, issues) written with the aid of AI agents.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InterceptOutput

func InterceptOutput(t *testing.T, file **os.File) func() string

InterceptOutput replaces what 'file' points to (normally os.Stdout) with a pipe and returns the 'readReset' function. The 'readReset' function returns what has been written to 'file' and resets 'file' to point to the original.

Example:

// Replace what is pointed to by os.Stdout (note the &):
read := rosina.InterceptOutput(t, &os.Stdout)
// Here call the SUT, something that writes to os.Stdout.
// Once done, call read() and validate the output:
out := read()

Types

This section is empty.

Directories

Path Synopsis
internal/diff
Package diff computes differences between text files or strings.
Package diff computes differences between text files or strings.
internal/diff/lcs
package lcs contains code to find longest-common-subsequences (and diffs)
package lcs contains code to find longest-common-subsequences (and diffs)
internal/diff/myers
Package myers implements the Myers diff algorithm.
Package myers implements the Myers diff algorithm.
internal/diffp
Package diffp implements a basic diff algorithm equivalent to patience diff.
Package diffp implements a basic diff algorithm equivalent to patience diff.

Jump to