Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InterceptOutput ¶
InterceptOutput replaces what 'file' points to (normally os.Stdout) with a pipe and returns the 'readReset' function. The 'readReset' function returns what has been written to 'file' and resets 'file' to point to the original.
Example:
// Replace what is pointed to by os.Stdout (note the &): read := rosina.InterceptOutput(t, &os.Stdout) // Here call the SUT, something that writes to os.Stdout. // Once done, call read() and validate the output: out := read()
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
internal/diff
Package diff computes differences between text files or strings.
|
Package diff computes differences between text files or strings. |
|
internal/diff/lcs
package lcs contains code to find longest-common-subsequences (and diffs)
|
package lcs contains code to find longest-common-subsequences (and diffs) |
|
internal/diff/myers
Package myers implements the Myers diff algorithm.
|
Package myers implements the Myers diff algorithm. |
|
internal/diffp
Package diffp implements a basic diff algorithm equivalent to patience diff.
|
Package diffp implements a basic diff algorithm equivalent to patience diff. |
Click to show internal directories.
Click to hide internal directories.